@@ -22,9 +22,9 @@ dsairmmenu <- function() {
 }
 
 #needed to prevent NOTE messages on CRAN checks
-#most of those are from the ggplot commands in the generate_ functions,
-#the last one is from the subset function in the fit functions
-utils::globalVariables(c("xvals", "yvals", "varnames","IDvar","style","Condition"))
+#comes because the data has that name
+#not sure how to prevent otherwise
+utils::globalVariables(c("hayden96flu","txtime"))
 
 
 .onAttach <- function(libname, pkgname){
